@@ -33,12 +33,12 @@ def _json_serial(obj):
 class PatrowlEngine:
     """Class definition of PatrowlEngine."""
 
-    def __init__(self, app, base_dir, name, max_scans=DEFAULT_APP_MAXSCANS):
+    def __init__(self, app, base_dir, name, max_scans=DEFAULT_APP_MAXSCANS, version=0):
         """Initialise a new PatrowlEngine."""
         self.app = app
         self.base_dir = str(base_dir)
         self.name = name
-        self.version = 0
+        self.version = version
         self.description = ""
         self.allowed_asset_types = []
         self.options = {}
@@ -279,7 +279,9 @@ class PatrowlEngine:
             return jsonify(res)
 
         for t in self.scans[scan_id]['threads']:
-            t._Thread__stop()
+            t.join()
+            self.scans[scan_id]['threads'].remove(t)
+            # t._Thread__stop()
         self.scans[scan_id]['status'] = "STOPPED"
         self.scans[scan_id]['finished_at'] = int(time.time() * 1000)
 
@@ -351,7 +353,6 @@ class PatrowlEngine:
         issues = []
         summary = {}
 
-        # scan = self.scans[scan_id]
         nb_vulns = {
             "info": 0,
             "low": 0,
